import xbmc
import xbmcgui
import xbmcaddon
import urllib.request
import json
import xml.etree.ElementTree as ET
import os

class GitLabMonitor(xbmc.Monitor):
    def __init__(self):
        super().__init__()
        self.addon = xbmcaddon.Addon('program.koddomainsupdate')
        self.addon_path = self.addon.getAddonInfo('path')
        self.addon_xml_path = os.path.join(self.addon_path, 'addon.xml')
        self.gitlab_api_url = 'https://gitlab.com/api/v4/projects/personal4143605%2Fkod-domains-update/repository/files/channels.json?ref=main'
        
    def get_current_commit_id(self):
        try:
            tree = ET.parse(self.addon_xml_path)
            root = tree.getroot()
            commit_id = root.find(".//channelsjson/commit_id")
            return commit_id.text if commit_id is not None else "initial"
        except Exception as e:
            xbmc.log(f"Error reading commit_id from addon.xml: {str(e)}", xbmc.LOGERROR)
            return "initial"
    
    def check_gitlab_update(self):
        try:
            req = urllib.request.Request(
                self.gitlab_api_url,
                headers={
                    'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/91.0.4472.124 Safari/537.36',
                    'Referer': 'https://gitlab.com/'
                }
            )
            
            with urllib.request.urlopen(req, timeout=10) as response:
                data = json.loads(response.read().decode('utf-8'))
            
            new_commit_id = data.get('last_commit_id', '')[:8]  # Get first 8 chars
            current_commit_id = self.get_current_commit_id()
            
            # Show notification if commits are different
            if new_commit_id and new_commit_id != current_commit_id:
                xbmcgui.Dialog().notification(
                    'KOD domains update',
                    'Il file channels.json è cambiato, apri KOD domains updater per aggiornarlo',
                    xbmcgui.NOTIFICATION_INFO,
                    5000
                )
                
        except Exception as e:
            xbmc.log(f"Error checking GitLab updates: {str(e)}", xbmc.LOGERROR)

if __name__ == '__main__':
    monitor = GitLabMonitor()
    
    # Initial check on startup
    monitor.check_gitlab_update()
    
    # Keep the service running and check periodically
    while not monitor.abortRequested():
        if monitor.waitForAbort(3600):  # Check every hour
            break
        monitor.check_gitlab_update()